==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-61.js <==
dispMUA.arDispMUAAllocation["a"] =
{
  "allaire coldfusion application server" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "alerts delivery system, marketwatch" : [ "marketwatch.png" , "http://www.marketwatch.com/" ] ,
  "allegro software rommailer" : [ "allegro.png" , "http://www.allegrosoft.com/rommailer.html" ] ,
  "adobe photoshop services" : [ "photoshop.png" , "http://www.adobe.com/products/photoshop/" ] ,
  "add2it mailresponder pro" : [ "mailresponderpro.png" , "http://www.mailresponderpro.com/" ] ,
  "activexperts activeemail" : [ "activexperts.png" , "http://www.activexperts.com/activemail/" ] ,
  "auto-responder - id.kom" : [ "idkom_de.png" , "http://www.idkom.de/" ] ,
  "activxperts activemail" : [ "activexperts.png" , "http://www.activexperts.com/activemail/" ] ,
  "arena internet mailer" : [ "arena-internet-mailer.png" , "http://arena-internet-mailer.org/" ] ,
  "apple mobileme mailer" : [ "apple_mobileme.png" , "http://www.apple.com/mobileme/" ] ,
  "akna e-mail marketing" : [ "akna.png" , "http://www.akna.com.br/" ] ,
  "a+a exist-info sender" : [ "exist_ru.png" , "http://www.exist.ru/" ] ,
  "asp component bundle" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "apsis newsletter pro" : [ "apsis.png" , "http://www.nyhetsbrev.biz/" ] ,
  "adrom e-mail manager" : [ "adrom_net.png" , "http://www.adrom.net/" ] ,
  "aconon mail software" : [ "aconon.png" , "http://www.aconon.de/" ] ,
  "auctionweb - mailer" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" ] ,
  "at&t message center" : [ "att.png" , "http://www.att.com/" ] ,
  "astrocenter-mailer" : [ "astrocenter.png" , "http://www.astrocenter.de/" ] ,
  "animexx mailritter" : [ "animexx.png" , "http://www.animexx.com/" ] ,
  "amicron mailoffice" : [ "amicron.png" , "http://www.amicron.org/" ] ,
  "adiscon simplemail" : [ "simplemail.png" , "http://www.simplemail.adiscon.com/" ] ,
  "apple .mac mailer" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "allegro's promail" : [ "allegro_biz.png" , "http://www.allegro.biz/promail.htm" ] ,
  "agnitas ag/conrad" : [ "conrad.png" , "http://www.conrad.de/" ] ,
  "animation mailer" : [ "animecha.png" , "http://www.animecha.com/" ] ,
  "akio mail center" : [ "akio.png" , "http://www.akio-solutions.com/" ] ,
  "anawave gravity" : [ "anawave-gravity.png" , "http://www.anawave.com/" ] ,
  "americasnet.com" : [ "americasnet_com.png" , "http://www.americasnet.com/" ] ,
  "ambit new media" : [ "ambit.png" , "http://www.ambitnewmedia.com/" ] ,
  "advalvas mailer" : [ "advalvas.png" , "http://www.advalvas.be/" ] ,
  "admin pro tools" : [ "adminprotools.png" , "http://www.adminprotools.com/" ] ,
  "axigen webmail" : [ "axigen.png" , "http://www.axigen.com/" ] ,
  "agonet webmail" : [ "agonet.png" , "http://www.agonet.it/" ] ,
  "acro media inc" : [ "acromedia.png" , "http://www.acromediainc.com/" ] ,
  "aconon.de mail" : [ "aconon.png" , "http://www.aconon.de/" ] ,
  "atlantisworld" : [ "atlantisworld.png" , "http://www.atlantisworld.it/" ] ,
  "aster webmail" : [ "aster.png" , "http://www.aster.pl/" ] ,
  "aspheria mail" : [ "aspheria.png" , "http://www.aspheria.com/" ] ,
  "argentina.com" : [ "argentina_com.png" , "http://www.argentina.com/" ] ,
  "aranay mailer" : [ "aranay.png" , "http://www.aranay.com/" ] ,
  "aport webmail" : [ "aport.png" , "http://www.aport.ru/" ] ,
  "amiga newsrog" : [ "amiga.png" , "http://sourceforge.net/projects/newsrog" ] ,
  "alice-webmail" : [ "alice.png" , "http://www.alice-dsl.de/" ] ,
  "activemaillib" : [ "phpclasses.png" , "http://georgiost.users.phpclasses.org/browse/package/2145.html" ] ,
  "abricoomailer" : [ "abricoo.png" , "http://www.abricoo.com/" ] ,
  "atlas mailer" : [ "atlas.png" , "http://www.data-trak.com/atlas_mailer.php" ] ,
  "aspa webmail" : [ "aspa_cz.png" , "http://www.aspa.cz/" ] ,
  "agendus mail" : [ "agendus.png" , "http://www.iambic.com/" ] ,
  "afs-kaufmann" : [ "afs-software.png" , "http://www.afs-software.de/" ] ,
  "activitymail" : [ "activitymail.png" , "http://search.cpan.org/dist/activitymail/" ] ,
  "activemail v" : [ "activemail-cibenix.png" , "http://www.cibenix.com/" ] ,
  "active! mail" : [ "active_mail_jp.png" , "http://activemail.jp/" ] ,
  "aboutspecial" : [ "about_com.png" , "http://www.about.com/" ] ,
  "ability mail" : [ "abilitymail.png" , "http://www.code-crafters.com/abilitymailserver/" ] ,
  "auto mailer" : [ "auto_mailer.png" , "http://www.automsw.com/" ] ,
  "aspnetemail" : [ "aspnetemail.png" , "http://www.aspnetemail.com/" ] ,
  "asp smtpsvg" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "apollo mail" : [ "apollo_mail.png" , "http://www.apollomail.com/" ] ,
  "aon webmail" : [ "aon.png" , "http://www.aon.at/" ] ,
  "amtangee(r)" : [ "amtangee.png" , "http://www.amtangee.com/" ] ,
  "aim webmail" : [ "aol.png" , "http://www.aol.com/" ] ,
  "active.mail" : [ "active.mail.png" , "http://nazwa.pl/serwery-activemail.html" ] ,
  "aborange.de" : [ "aborange.png" , "http://www.aborange.de/" ] ,
  "applixware" : [ "vistasource.png" , "http://www.vistasource.com/en/applixware.php" ] ,
  "apple mail" : [ "apple_mail.png" , "http://www.apple.com/macosx/features/mail/" ] ,
  "agooza.net" : [ "agooza.png" , "http://www.agooza.net/" ] ,
  "activemail" : [ "activemail.png" , "http://www.activeup.com/" ] ,
  "a1 webmail" : [ "a1webmail.png" , "http://www.a1.net/" ] ,
  "anglemail" : [ "anglemail.png" , "http://www.anglemail.org/" ] ,
  "amos mail" : [ "spectec.png" , "http://www.spectec.net/maritime_mail.asp" ] ,
  "alphamail" : [ "alphamail.png" , "http://alphamail.sourceforge.net/" ] ,
  "al-mail32" : [ "almail.png" , "http://www.almail.com/" ] ,
  "agregator" : [ "viadeo.png" , "http://www.viadeo.com/" ] ,
  "activefax" : [ "activefax.png" , "http://www.activefax-software.de/" ] ,
  "ac mailer" : [ "12all.png" , "http://activecampaign.com/12all/" ] ,
  "avantfax" : [ "avantfax.png" , "http://www.avantfax.com/" ] ,
  "aspqmail" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "altobase" : [ "altobase.png" , "http://altobase.jp/asp/" ] ,
  "aeromail" : [ "aeromail.png" , "http://the.cushman.net/reverb/aeromail/" ] ,
  "acmemail" : [ "acmemail.png" , "http://www.astray.com/acmemail/" ] ,
  "accucast" : [ "accucast.png" , "http://www.accucast.com/" ] ,
  "azureus" : [ "azureus.png" , "http://azureus.sourceforge.net/" ] ,
  "azet.sk" : [ "azet_sk.png" , "http://www.azet.sk/" ] ,
  "atmail " : [ "atmail.png" , "http://www.atmail.com/" ] ,
  "aspmail" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "asp.net" : [ "asp_net.png" , "http://www.asp.net/" ] ,
  "arcabit" : [ "arcabit.png" , "http://www.arcabit.com/" ] ,
  "arachne" : [ "arachne.png" , "http://browser.arachne.cz/" ] ,
  "amember" : [ "cgi-central_net.png" , "http://www.amember.com/" ] ,
  "alpha-g" : [ "alpha-g.png" , "http://www.alphagconsulting.com/" ] ,
  "ak-mail" : [ "ak-mail.png" , "http://www.akmail.com/" ] ,
  "airmail" : [ "airmail.png" , "http://www.air.co.jp/products/air_mail_c/amc.html" ] ,
  "agnitas" : [ "agnitas.png" , "http://www.agnitas.de/" ] ,
  "aethera" : [ "aethera.png" , "http://www.thekompany.com/projects/aethera/" ] ,
  "adtoone" : [ "adtoone.png" , "http://www.zaisoft.com/adtoone/" ] ,
  "addemar" : [ "addemar.png" , "http://www.addemar.com/" ] ,
  "abvmail" : [ "abvmail.png" , "http://www.abv.bg/" ] ,
  "axinom" : [ "axinom.png" , "http://www.axinom.com/" ] ,
  "aweber" : [ "aweber.png" , "http://www.aweber.com/" ] ,
  "avenum" : [ "avenum.png" , "http://www.avenum.com/" ] ,
  "avast!" : [ "avast.png" , "http://www.avast.ru/" ] ,
  "arclab" : [ "amlc.png" , "http://www.arclab.com/products/amlc/" ] ,
  "aperto" : [ "aperto.png" , "http://www.aperto.de/" ] ,
  "alpine" : [ "alpine.png" , "http://www.washington.edu/alpine/" ] ,
  "adjoli" : [ "adjoli.png" , "http://www.adjoli.de/" ] ,
  "acumen" : [ "acumen.png" , "http://www.cyberwolf.com/" ] ,
  "arcor" : [ "arcor.png" , "http://www.arcor.de/" ] ,
  "adele" : [ "gnupp-adele.png" , "http://www.gnupp.de/" ] ,
  "airt" : [ "airt.png" , "http://sourceforge.net/projects/airt" ] ,
  "aol" : [ "aol.png" , "http://www.aol.com/" ] ,
  "afp" : [ "afp.png" , "http://www.afpnet.org/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-61.js <==
dispMUA.arDispMUAAllocation["a"] =
{
  "allaire coldfusion application server" : [ "coldfusion.png" , "http://www.adobe.com/products/coldfusion/" ] ,
  "alerts delivery system, marketwatch" : [ "marketwatch.png" , "http://www.marketwatch.com/" ] ,
  "allegro software rommailer" : [ "allegro.png" , "http://www.allegrosoft.com/rommailer.html" ] ,
  "axigen outlook connector" : [ "axigen.png" , "http://www.axigen.com/" ] ,
  "adobe photoshop services" : [ "photoshop.png" , "http://www.adobe.com/products/photoshop/" ] ,
  "add2it mailresponder pro" : [ "mailresponderpro.png" , "http://www.mailresponderpro.com/" ] ,
  "activexperts activeemail" : [ "activexperts.png" , "http://www.activexperts.com/activemail/" ] ,
  "auto-responder - id.kom" : [ "idkom_de.png" , "http://www.idkom.de/" ] ,
  "a/i webmail (roundcube" : [ "roundcube.png" , "http://www.roundcube.net/" ] ,
  "activxperts activemail" : [ "activexperts.png" , "http://www.activexperts.com/activemail/" ] ,
  "arena internet mailer" : [ "arena-internet-mailer.png" , "http://arena-internet-mailer.org/" ] ,
  "apple mobileme mailer" : [ "apple_mobileme.png" , "http://www.apple.com/mobileme/" ] ,
  "akna e-mail marketing" : [ "akna.png" , "http://www.akna.com.br/" ] ,
  "a+a exist-info sender" : [ "exist_ru.png" , "http://www.exist.ru/" ] ,
  "asp component bundle" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "apsis newsletter pro" : [ "apsis.png" , "http://www.nyhetsbrev.biz/" ] ,
  "adrom e-mail manager" : [ "adrom_net.png" , "http://www.adrom.net/" ] ,
  "aconon mail software" : [ "aconon.png" , "http://www.aconon.de/" ] ,
  "auctionweb - mailer" : [ "auktionmaster.png" , "http://www.auktionmaster.de/" ] ,
  "at&t message center" : [ "att.png" , "http://www.att.com/" ] ,
  "astrocenter-mailer" : [ "astrocenter.png" , "http://www.astrocenter.de/" ] ,
  "animexx mailritter" : [ "animexx.png" , "http://www.animexx.com/" ] ,
  "amicron mailoffice" : [ "amicron.png" , "http://www.amicron.org/" ] ,
  "adiscon simplemail" : [ "simplemail.png" , "http://www.simplemail.adiscon.com/" ] ,
  "apple .mac mailer" : [ "apple_store.png" , "http://store.apple.com/" ] ,
  "allegro's promail" : [ "allegro_biz.png" , "http://www.allegro.biz/promail.htm" ] ,
  "agnitas ag/conrad" : [ "conrad.png" , "http://www.conrad.de/" ] ,
  "animation mailer" : [ "animecha.png" , "http://www.animecha.com/" ] ,
  "akio mail center" : [ "akio.png" , "http://www.akio-solutions.com/" ] ,
  "anawave gravity" : [ "anawave-gravity.png" , "http://www.anawave.com/" ] ,
  "americasnet.com" : [ "americasnet_com.png" , "http://www.americasnet.com/" ] ,
  "ambit new media" : [ "ambit.png" , "http://www.ambitnewmedia.com/" ] ,
  "advalvas mailer" : [ "advalvas.png" , "http://www.advalvas.be/" ] ,
  "admin pro tools" : [ "adminprotools.png" , "http://www.adminprotools.com/" ] ,
  "axigen webmail" : [ "axigen.png" , "http://www.axigen.com/" ] ,
  "anneca intouch" : [ "anneca-intouch.png" , "http://www.intouch-crm.cz/" ] ,
  "agonet webmail" : [ "agonet.png" , "http://www.agonet.it/" ] ,
  "acro media inc" : [ "acromedia.png" , "http://www.acromediainc.com/" ] ,
  "aconon.de mail" : [ "aconon.png" , "http://www.aconon.de/" ] ,
  "atlantisworld" : [ "atlantisworld.png" , "http://www.atlantisworld.it/" ] ,
  "aster webmail" : [ "aster.png" , "http://www.aster.pl/" ] ,
  "aspheria mail" : [ "aspheria.png" , "http://www.aspheria.com/" ] ,
  "argentina.com" : [ "argentina_com.png" , "http://www.argentina.com/" ] ,
  "aranay mailer" : [ "aranay.png" , "http://www.aranay.com/" ] ,
  "aport webmail" : [ "aport.png" , "http://www.aport.ru/" ] ,
  "amiga newsrog" : [ "amiga.png" , "http://sourceforge.net/projects/newsrog" ] ,
  "alice-webmail" : [ "alice.png" , "http://www.alice-dsl.de/" ] ,
  "akibaoomailer" : [ "akibaoo.png" , "http://www.akibaoo.co.jp/" ] ,
  "activemaillib" : [ "phpclasses.png" , "http://georgiost.users.phpclasses.org/browse/package/2145.html" ] ,
  "abricoomailer" : [ "abricoo.png" , "http://www.abricoo.com/" ] ,
  "atlas mailer" : [ "atlas.png" , "http://www.data-trak.com/atlas_mailer.php" ] ,
  "aspa webmail" : [ "aspa_cz.png" , "http://www.aspa.cz/" ] ,
  "ampartner.pl" : [ "ampartner_pl.png" , "http://www.ampartner.pl/" ] ,
  "agendus mail" : [ "agendus.png" , "http://www.iambic.com/" ] ,
  "afs-kaufmann" : [ "afs-software.png" , "http://www.afs-software.de/" ] ,
  "activitymail" : [ "activitymail.png" , "http://search.cpan.org/dist/activitymail/" ] ,
  "activemail v" : [ "activemail-cibenix.png" , "http://www.cibenix.com/" ] ,
  "active! mail" : [ "active_mail_jp.png" , "http://activemail.jp/" ] ,
  "aboutspecial" : [ "about_com.png" , "http://www.about.com/" ] ,
  "ability mail" : [ "abilitymail.png" , "http://www.code-crafters.com/abilitymailserver/" ] ,
  "auto mailer" : [ "auto_mailer.png" , "http://www.automsw.com/" ] ,
  "atu webmail" : [ "atu.png" , "http://www.atu.eu/" ] ,
  "aspnetemail" : [ "aspnetemail.png" , "http://www.aspnetemail.com/" ] ,
  "asp smtpsvg" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "apollo mail" : [ "apollo_mail.png" , "http://www.apollomail.com/" ] ,
  "aon webmail" : [ "aon.png" , "http://www.aon.at/" ] ,
  "amtangee(r)" : [ "amtangee.png" , "http://www.amtangee.com/" ] ,
  "aim webmail" : [ "aol.png" , "http://www.aol.com/" ] ,
  "active.mail" : [ "active.mail.png" , "http://nazwa.pl/serwery-activemail.html" ] ,
  "aborange.de" : [ "aborange.png" , "http://www.aborange.de/" ] ,
  "applixware" : [ "vistasource.png" , "http://www.vistasource.com/en/applixware.php" ] ,
  "apple mail" : [ "apple_mail.png" , "http://www.apple.com/macosx/features/mail/" ] ,
  "agooza.net" : [ "agooza.png" , "http://www.agooza.net/" ] ,
  "activemail" : [ "activemail.png" , "http://www.activeup.com/" ] ,
  "a1 webmail" : [ "a1webmail.png" , "http://www.a1.net/" ] ,
  "anglemail" : [ "anglemail.png" , "http://www.anglemail.org/" ] ,
  "amos mail" : [ "spectec.png" , "http://www.spectec.net/maritime_mail.asp" ] ,
  "alphamail" : [ "alphamail.png" , "http://alphamail.sourceforge.net/" ] ,
  "al-mail32" : [ "almail.png" , "http://www.almail.com/" ] ,
  "agregator" : [ "viadeo.png" , "http://www.viadeo.com/" ] ,
  "activefax" : [ "activefax.png" , "http://www.activefax-software.de/" ] ,
  "ac mailer" : [ "12all.png" , "http://activecampaign.com/12all/" ] ,
  "avantfax" : [ "avantfax.png" , "http://www.avantfax.com/" ] ,
  "aspqmail" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "altobase" : [ "altobase.png" , "http://altobase.jp/asp/" ] ,
  "aeromail" : [ "aeromail.png" , "http://the.cushman.net/reverb/aeromail/" ] ,
  "acmemail" : [ "acmemail.png" , "http://www.astray.com/acmemail/" ] ,
  "accucast" : [ "accucast.png" , "http://www.accucast.com/" ] ,
  "a.net.pl" : [ "a_net_pl.png" , "http://www.a.net.pl/" ] ,
  "azureus" : [ "azureus.png" , "http://azureus.sourceforge.net/" ] ,
  "azet.sk" : [ "azet_sk.png" , "http://www.azet.sk/" ] ,
  "avstore" : [ "avstore.png" , "http://www.avstore.ro/" ] ,
  "atmail " : [ "atmail.png" , "http://www.atmail.com/" ] ,
  "aspmail" : [ "serverobjects.png" , "http://www.serverobjects.com/products.htm" ] ,
  "asp.net" : [ "asp_net.png" , "http://www.asp.net/" ] ,
  "arcabit" : [ "arcabit.png" , "http://www.arcabit.com/" ] ,
  "arachne" : [ "arachne.png" , "http://browser.arachne.cz/" ] ,
  "amember" : [ "cgi-central_net.png" , "http://www.amember.com/" ] ,
  "alpha-g" : [ "alpha-g.png" , "http://www.alphagconsulting.com/" ] ,
  "ak-mail" : [ "ak-mail.png" , "http://www.akmail.com/" ] ,
  "airmail" : [ "airmail.png" , "http://www.air.co.jp/products/air_mail_c/amc.html" ] ,
  "agnitas" : [ "agnitas.png" , "http://www.agnitas.de/" ] ,
  "aethera" : [ "aethera.png" , "http://www.thekompany.com/projects/aethera/" ] ,
  "adtoone" : [ "adtoone.png" , "http://www.zaisoft.com/adtoone/" ] ,
  "addemar" : [ "addemar.png" , "http://www.addemar.com/" ] ,
  "abvmail" : [ "abvmail.png" , "http://www.abv.bg/" ] ,
  "axinom" : [ "axinom.png" , "http://www.axinom.com/" ] ,
  "aweber" : [ "aweber.png" , "http://www.aweber.com/" ] ,
  "avenum" : [ "avenum.png" , "http://www.avenum.com/" ] ,
  "avast!" : [ "avast.png" , "http://www.avast.ru/" ] ,
  "arclab" : [ "amlc.png" , "http://www.arclab.com/products/amlc/" ] ,
  "aperto" : [ "aperto.png" , "http://www.aperto.de/" ] ,
  "alpine" : [ "alpine.png" , "http://www.washington.edu/alpine/" ] ,
  "adjoli" : [ "adjoli.png" , "http://www.adjoli.de/" ] ,
  "acumen" : [ "acumen.png" , "http://www.cyberwolf.com/" ] ,
  "arcor" : [ "arcor.png" , "http://www.arcor.de/" ] ,
  "adele" : [ "gnupp-adele.png" , "http://www.gnupp.de/" ] ,
  "airt" : [ "airt.png" , "http://sourceforge.net/projects/airt" ] ,
  "aol" : [ "aol.png" , "http://www.aol.com/" ] ,
  "afp" : [ "afp.png" , "http://www.afpnet.org/" ] ,
}
